create table account (
  _id integer primary key autoincrement,
  label text,
  selected integer,
  last_updated integer,
  last_unread_crawl integer,
  source integer not null default 0,
  unread_server integer,
  unread_local integer,
  unread_cached integer,
  refresh_token text,
  access_token text,
  account_type text,
  user_id text,
  url text
);

create table cat (
  _id integer primary key,
  cat_id text not null,
  label text not null,
  account_id integer not null references account(_id) on delete cascade,
  updated integer not null default 0,
  sortid integer,
  feed_count integer,
  unread_server integer,
  unread_local integer,
  unread_cached integer
);

create index if not exists IDX_CAT_ID on cat(cat_id);
create index if not exists IDX_CAT_ACCOUNT_ID on cat(account_id);

create table feed(
  _id integer primary key,
  feed_id text not null,
  title text not null,
  account_id integer not null references account(_id) on delete cascade,
  updated integer not null default 0,
  sortid integer,
  broadcast integer,
  custom_settings int not null default 0,
  load_content text not null default 'NEVER',
  load_audio int not null default 0,
  load_video int not null default 0,
  load_images int not null default 0,
  view_open text not null default 'RSS',
  open_cached int not null default 1,
  ignore int not null default 0,
  base_link text,
  mobilizer text,
  unread_server integer,
  unread_local integer,
  unread_cached integer,
  first_item_msec integer
);

create index if not exists IDX_FEED_ID on feed(feed_id);
create index if not exists IDX_FEED_ACCOUNT_ID on feed(account_id);

create table feed_cat(
  cat_id integer references cat(_id) on delete cascade,
  feed_id integer references feed(_id) on delete cascade,
  sortid integer,
  updated integer not null default 0,
  primary key(feed_id, cat_id)
);

create index if not exists IDX_FEED_CAT_CAT on feed_cat(cat_id);
create index if not exists IDX_FEED_CAT_FEED on feed_cat(feed_id);

create table post(
  _id integer primary key autoincrement,
  feed_id integer references feed(_id) on delete cascade,
  google_id text,
  title text,
  published integer,
  updated integer,
  link text,
  summary text,
  author text,
  crawl integer,
  images_loaded integer not null default 0,
  read_status integer not null default 0,
  starred_status integer not null default 0,
  via text,
  liking_users integer default 0,
  continuation text,
  actual integer,
  enclosure_link text,
  enclosure_type integer default 0 not null,
  enclosure_type_s text,
  content_loaded integer not null default 0,
  enclosure_loaded integer not null default 0,
  image text,
  thumbnail_cached integer
);

create index if not exists IDX_POST_READ on post(read_status);
create index if not exists IDX_POST_ID on post(google_id);
create index if not exists IDX_POST_FEED_ID on post(feed_id);
create unique index if not exists IDX_POST_ID_UN on post(google_id, feed_id);

create table exc(
  _id integer primary key autoincrement,
  stacktrace text not null
);

create table post_cat(
  cat_id integer references cat(_id) on delete cascade,
  post_id integer references post(_id) on delete cascade,
  crawl integer,
  state integer not null default 0,
  primary key(post_id, cat_id)
);

create index if not exists IDX_POST_CAT_CAT on post_cat(cat_id);
create index if not exists IDX_POST_CAT_POST on post_cat(post_id);
create index if not exists IDX_POST_CAT_POST on post_cat(state);

create view root_feed_item as
  select
          0   _id,
          _id account_id,
          'all' str_id,
          'all' label,
          'ALL' type,
          null base_link,
          unread_local,
          unread_cached,
          0 feed_count,
          -1000 sortid
  from account
  union all
  select  _id,
          account_id,
          cat_id str_id,
          label,
          'CAT' type,
          null base_link,
          unread_local,
          unread_cached,
          feed_count,
          sortid
  from cat
  union all
  select  _id,
          account_id,
          feed_id str_id,
          title label,
          'FEED' type,
          base_link,
          unread_local,
          unread_cached,
          0 feed_count,
          sortid
  from feed
  where (broadcast is null or broadcast = 0)
    and not exists(select 1 from feed_cat where feed_id = _id);

create view feed_item as
select f._id _id,
       f.account_id account_id,
       f.feed_id str_id,
       f.title label,
       'feed' type,
       f.unread_local unread_local,
       f.unread_cached unread_cached,
       f.base_link base_link,
       0 feed_count,
       f.sortid sortid,
       fc.cat_id cat_id
  from feed_cat fc
  left outer join feed f
    on fc.feed_id = f._id;

create view feed_lenta as
select p._id _id,
      p.feed_id feed_id,
      0 cat_id,
      p.google_id google_id,
      p.title title,
      p.published published,
      p.updated updated,
      p.link link,
      p.summary summary,
      p.author author,
      p.crawl crawl,
      p.read_status read_status,
      p.starred_status starred_status,
      p.images_loaded images_loaded,
      p.via via,
      p.liking_users liking_users,
      p.continuation continuation,
      p.actual actual,
      p.enclosure_link enclosure_link,
      p.enclosure_type enclosure_type,
      p.enclosure_type_s enclosure_type_s,
      p.content_loaded content_loaded,
      p.enclosure_loaded enclosure_loaded,
      p.image image,
      f.title feed_title,
      f.open_cached open_cached,
      f.load_content load_content,
      f.load_audio load_audio,
      f.load_video load_video,
      f.view_open view_open,
      f.account_id account_id,
      f.custom_settings custom_settings,
      f.mobilizer mobilizer,
      p.thumbnail_cached thumbnail_cached
  from post p
  left outer join feed f on f._id = p.feed_id;

create view cat_lenta as
select p._id _id,
      p.feed_id feed_id,
      pc.cat_id cat_id,
      p.google_id google_id,
      p.title title,
      p.published published,
      p.updated updated,
      p.link link,
      p.summary summary,
      p.author author,
      pc.crawl crawl,
      p.read_status read_status,
      p.starred_status starred_status,
      p.images_loaded images_loaded,
      p.via via,
      p.liking_users liking_users,
      p.continuation continuation,
      p.actual actual,
      p.enclosure_link enclosure_link,
      p.enclosure_type enclosure_type,
      p.enclosure_type_s enclosure_type_s,
      p.content_loaded content_loaded,
      p.enclosure_loaded enclosure_loaded,
      p.image image,
      f.title feed_title,
      f.open_cached open_cached,
      f.load_content load_content,
      f.load_audio load_audio,
      f.load_video load_video,
      f.view_open view_open,
      f.account_id account_id,
      f.custom_settings custom_settings,
      f.mobilizer mobilizer,
      p.thumbnail_cached thumbnail_cached
  from post_cat pc, post p, feed f
  where f._id = p.feed_id and pc.post_id = p._id and pc.state <> 2;

create table inter(
   start_crawl integer not null,
   end_crawl integer not null,
   account_id integer not null,
   stream_id integer not null,
   stream_type integer not null,
   unread integer not null,
   status integer not null
);

create index idx_inter_start on inter(start_crawl);
create index idx_inter_end on inter(end_crawl);

create index idx_inter_account on inter(account_id);
create index idx_inter_status on inter(status);
create index idx_inter_stream on inter(stream_id, stream_type, unread);

create table id_gen (
  _id integer primary key autoincrement,
  temp integer
);

create table status_cache (
  post_id integer,
  add_state text,
  del_state text,
  has_status integer,
  primary key(post_id, add_state, del_state)
);